@@ -36,20 +36,28 @@ typedef struct _ReplaceInfo
   gboolean arrow;
   gboolean ignorecase;
   gchar *src, *dst;
-  GdkPoint start, end;
 } ReplaceInfo;
 
 
+extern GtkWidget *repinfo_box;
+
+
 /******************************************************************************
 *                                                                             *
-* ja:置換情報ダイアログ関数群                                                 *
+* ja:置換情報ボックス関数群                                                   *
 *                                                                             *
 ******************************************************************************/
-/*  ja:置換情報ダイアログ表示
+/*  ja:置換情報ボックス取得
+    RET,置換情報ボックス                                                    */
+GtkWidget *
+repinfo_box_get_widget (void);
+
+
+/*  ja:置換情報ボックス表示
      ri,置換情報
     RET,REPLACE_OK,REPLACE_NEXT,REPLACE_ALL,REPLACE_CANCEL                  */
 gint
-repinfo_dialog (ReplaceInfo *ri);
+repinfo_run (ReplaceInfo *ri);
 
 
 G_END_DECLS
