@@ -1,6 +1,6 @@
 /*
     Text maid
-    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org
+    copyright (c) 1998-2010 Kazuki Iwamoto http://www.maid.org/ iwm@maid.org
 
     This program is free software: you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -37,7 +37,7 @@ version_dialog (void)
   GtkWidget *text, *scroll;
 const static gchar *authors =
 "Supreme Programmer:\n"
-" Kazuki IWAMOTO <iwm@maid.org>\n"
+" Kazuki Iwamoto <iwm@maid.org>\n"
 "\n"
 "Icons Author:\n"
 " from GTK+ Stock Icons\n"
